@@ -226,6 +226,11 @@ pub enum ExecuteMsg {
     UpdateAdmin {
         admin: Option<String>,
     },
+    /// Alter config values
+    UpdateConfig {
+        min_weight: Option<u64>,
+        max_validators: Option<u32>,
+    },
     /// Links info.sender (operator) to this Tendermint consensus key.
     /// The operator cannot re-register another key.
     /// No two operators may have the same consensus_key.
@@ -276,8 +281,10 @@ pub enum QueryMsg {
     },
 
     /// List the current validator set, sorted by power descending
-    /// (no pagination - reasonable limit from max_validators)
-    ListActiveValidators {},
+    ListActiveValidators {
+        start_after: Option<String>,
+        limit: Option<u32>,
+    },
 
     /// This will calculate who the new validators would be if
     /// we recalculated end block right now.
@@ -312,6 +319,7 @@ pub struct OperatorResponse {
     pub pubkey: Pubkey,
     pub metadata: ValidatorMetadata,
     pub jailed_until: Option<JailingPeriod>,
+    pub active_validator: bool,
 }
 
 impl OperatorResponse {
@@ -325,12 +333,12 @@ impl OperatorResponse {
             pubkey: info.pubkey.into(),
             metadata: info.metadata,
             jailed_until: jailed_until.into(),
+            active_validator: info.active_validator,
         }
     }
 }
 
 #[derive(Serialize, Deserialize, Clone, PartialEq, JsonSchema, Debug)]
-#[serde(rename_all = "snake_case")]
 pub enum JailingPeriod {
     Forever {},
     Until(Expiration),
@@ -416,6 +424,13 @@ pub struct InstantiateResponse {
     pub rewards_contract: Addr,
 }
 
+#[derive(Serialize, Deserialize, Clone, PartialEq, JsonSchema, Debug)]
+#[serde(rename_all = "snake_case")]
+pub struct MigrateMsg {
+    pub min_weight: Option<u64>,
+    pub max_validators: Option<u32>,
+}
+
 #[cfg(test)]
 mod test {
     use super::*;
