@@ -39,7 +39,8 @@ pub fn contract_valset() -> Box<dyn Contract<TgradeMsg>> {
         crate::contract::query,
     )
     .with_sudo(crate::contract::sudo)
-    .with_reply(crate::contract::reply);
+    .with_reply(crate::contract::reply)
+    .with_migrate(crate::contract::migrate);
 
     Box::new(contract)
 }
@@ -391,6 +392,7 @@ impl SuiteBuilder {
 
         Suite {
             app,
+            valset_code_id: valset_id,
             valset,
             membership,
             distribution_contracts,
@@ -409,6 +411,8 @@ pub struct Suite {
     /// Multitest app
     #[derivative(Debug = "ignore")]
     app: TgradeApp,
+    /// The code id of the valset contract
+    valset_code_id: u64,
     /// tgrade-valset contract address
     valset: Addr,
     /// membership contract address
@@ -552,6 +556,23 @@ impl Suite {
         )
     }
 
+    pub fn update_config(
+        &mut self,
+        executor: &str,
+        min_weight: impl Into<Option<u64>>,
+        max_validators: impl Into<Option<u32>>,
+    ) -> AnyResult<AppResponse> {
+        self.app.execute_contract(
+            Addr::unchecked(executor),
+            self.valset.clone(),
+            &ExecuteMsg::UpdateConfig {
+                min_weight: min_weight.into(),
+                max_validators: max_validators.into(),
+            },
+            &[],
+        )
+    }
+
     pub fn slash(
         &mut self,
         executor: &str,
@@ -650,11 +671,18 @@ impl Suite {
         Ok(resp.validators)
     }
 
-    pub fn list_active_validators(&self) -> StdResult<Vec<ValidatorInfo>> {
-        let resp: ListActiveValidatorsResponse = self
-            .app
-            .wrap()
-            .query_wasm_smart(self.valset.clone(), &QueryMsg::ListActiveValidators {})?;
+    pub fn list_active_validators(
+        &self,
+        start_after: impl Into<Option<String>>,
+        limit: impl Into<Option<u32>>,
+    ) -> StdResult<Vec<ValidatorInfo>> {
+        let resp: ListActiveValidatorsResponse = self.app.wrap().query_wasm_smart(
+            self.valset.clone(),
+            &QueryMsg::ListActiveValidators {
+                start_after: start_after.into(),
+                limit: limit.into(),
+            },
+        )?;
 
         Ok(resp.validators)
     }
@@ -734,4 +762,15 @@ impl Suite {
             &[],
         )
     }
+
+    /// Migrates the contract to the same version (same code id), but possibly changing
+    /// some cfg values via MigrateMsg.
+    pub fn migrate(&mut self, addr: &str, msg: &MigrateMsg) -> AnyResult<AppResponse> {
+        self.app.migrate_contract(
+            Addr::unchecked(addr),
+            self.valset.clone(),
+            msg,
+            self.valset_code_id,
+        )
+    }
 }
